@@ -58,6 +58,9 @@
 #include <kdesktopfile.h>
 #include <kprotocolinfo.h>
 #include <kservicegroup.h>
+#include <kservicetypetrader.h>
+#include <kcmoduleinfo.h>
+#include <kcmodule.h>
 
 #include "navigatoritem.h"
 #include "navigatorappitem.h"
@@ -226,6 +229,28 @@ void Navigator::insertParentAppDocs( const QString &name, NavigatorItem *topItem
   }
 }
 
+void Navigator::insertKCMDocs( const QString &name, NavigatorItem *topItem, const QString &type )
+{
+  kDebug(1400) << "Requested IOSlave documents for ID " << name;
+
+  KService::List list;
+
+  if ( type == QString("kcontrol") ) {
+    list = KServiceTypeTrader::self()->query( "KCModule", "[X-KDE-ParentApp] == 'kcontrol'" );
+  } else {
+    list = KServiceTypeTrader::self()->query( "KCModule", "[X-KDE-ParentApp] == 'kinfocenter'" );
+  }
+
+  NavigatorItem *prevItem = 0;
+  for ( KService::List::const_iterator it = list.begin(); it != list.end(); ++it )
+  {
+    KService::Ptr s = (*it);
+    KCModuleInfo m = KCModuleInfo::KCModuleInfo(s);
+    QString desktopFile = KStandardDirs::locate( "services", m.fileName() );
+    createItemFromDesktopFile( topItem, desktopFile );
+    }
+}
+
 void Navigator::insertIOSlaveDocs( const QString &name, NavigatorItem *topItem )
 {
   kDebug(1400) << "Requested IOSlave documents for ID " << name;
@@ -242,7 +267,7 @@ void Navigator::insertIOSlaveDocs( const QString &name, NavigatorItem *topItem )
       // First parameter is ignored if second is an absolute path
       KUrl url(KUrl("help:/"), docPath);
       QString icon = KProtocolInfo::icon(*it);
-      if ( icon.isEmpty() ) icon = "document2";
+      if ( icon.isEmpty() ) icon = "text-plain";
       DocEntry *entry = new DocEntry( *it, url.url(), icon );
       NavigatorItem *item = new NavigatorItem( entry, topItem, prevItem );
       prevItem = item;
@@ -272,7 +297,7 @@ void Navigator::createItemFromDesktopFile( NavigatorItem *topItem,
       // First parameter is ignored if second is an absolute path
       KUrl url(KUrl("help:/"), docPath);
       QString icon = desktopFile.readIcon();
-      if ( icon.isEmpty() ) icon = "document2";
+      if ( icon.isEmpty() ) icon = "text-plain";
       DocEntry *entry = new DocEntry( desktopFile.readName(), url.url(), icon );
       NavigatorItem *item = new NavigatorItem( entry, topItem );
       item->setAutoDeleteDocEntry( true );
